==> devextreme-21.1.8-build-22033-1322.tgz: package/cjs/ui/scheduler/base/widgetObserver.js <==
/**
 * DevExtreme (cjs/ui/scheduler/base/widgetObserver.js)
 * Version: 21.1.7 (build 22033-1322)
 * Build date: Wed Feb 02 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _ui = _interopRequireDefault(require("../../widget/ui.widget"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var WidgetObserver = function(_Widget) {
    _inheritsLoose(WidgetObserver, _Widget);

    function WidgetObserver() {
        return _Widget.apply(this, arguments) || this
    }
    var _proto = WidgetObserver.prototype;
    _proto.notifyObserver = function(subject, args) {
        var observer = this.option("observer");
        if (observer) {
            observer.fire(subject, args)
        }
    };
    _proto.invoke = function() {
        var observer = this.option("observer");
        if (observer) {
            return observer.fire.apply(observer, arguments)
        }
    };
    return WidgetObserver
}(_ui.default);
var _default = WidgetObserver;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-21.1.10-build-22180-0309.tgz: package/cjs/ui/scheduler/base/widgetObserver.js <==
/**
 * DevExtreme (cjs/ui/scheduler/base/widgetObserver.js)
 * Version: 21.1.9 (build 22180-0309)
 * Build date: Wed Jun 29 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _ui = _interopRequireDefault(require("../../widget/ui.widget"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var WidgetObserver = function(_Widget) {
    _inheritsLoose(WidgetObserver, _Widget);

    function WidgetObserver() {
        return _Widget.apply(this, arguments) || this
    }
    var _proto = WidgetObserver.prototype;
    _proto.notifyObserver = function(subject, args) {
        var observer = this.option("observer");
        if (observer) {
            observer.fire(subject, args)
        }
    };
    _proto.invoke = function() {
        var observer = this.option("observer");
        if (observer) {
            return observer.fire.apply(observer, arguments)
        }
    };
    return WidgetObserver
}(_ui.default);
var _default = WidgetObserver;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;
